@@ -1,7 +1,9 @@
 package Regexp::Pattern;
 
-our $DATE = '2018-09-12'; # DATE
-our $VERSION = '0.2.8'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-07'; # DATE
+our $DIST = 'Regexp-Pattern'; # DIST
+our $VERSION = '0.2.12'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
@@ -49,13 +51,13 @@ sub import {
     while (@args) {
         my $arg = shift @args;
         my ($mod, $name0, $as, $prefix, $suffix,
-            $has_tag, $lacks_tag, $gen_args);
+            $has_tag, $lacks_tag, $has_tag_matching, $lacks_tag_matching, $gen_args);
         if ($arg eq 're') {
             *{"$caller\::re"} = \&re;
             next;
         } elsif ($arg =~ /\A(\w+(?:::\w+)*)::(\w+|\*)\z/) {
             ($mod, $name0) = ($1, $2);
-            ($as, $prefix, $suffix, $has_tag, $lacks_tag) =
+            ($as, $prefix, $suffix, $has_tag, $lacks_tag, $has_tag_matching, $lacks_tag_matching) =
                 (undef, undef, undef, undef, undef);
             $gen_args = {};
             while (@args >= 2 && $args[0] =~ /\A-?\w+\z/) {
@@ -74,6 +76,10 @@ sub import {
                     $has_tag = $v;
                 } elsif ($k eq '-lacks_tag') {
                     $lacks_tag = $v;
+                } elsif ($k eq '-has_tag_matching') {
+                    $has_tag_matching = ref $v eq 'Regexp' ? $v : qr/$v/;
+                } elsif ($k eq '-lacks_tag_matching') {
+                    $lacks_tag_matching = ref $v eq 'Regexp' ? $v : qr/$v/;
                 } elsif ($k !~ /\A-/) {
                     $gen_args->{$k} = $v;
                 } else {
@@ -102,6 +108,12 @@ sub import {
                 if (defined $lacks_tag) {
                     next if grep { $_ eq $lacks_tag } @$tags;
                 }
+                if (defined $has_tag_matching) {
+                    next unless grep { $_ =~ $has_tag_matching } @$tags;
+                }
+                if (defined $lacks_tag_matching) {
+                    next if grep { $_ =~ $lacks_tag_matching } @$tags;
+                }
                 push @names, $n;
             }
             unless (@names) {
@@ -141,7 +153,7 @@ Regexp::Pattern - Convention/framework for modules that contain collection of re
 
 =head1 VERSION
 
-This document describes version 0.2.8 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2018-09-12.
+This document describes version 0.2.12 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2020-02-07.
 
 =head1 SYNOPSIS
 
@@ -171,9 +183,15 @@ that is only 1-level deep):
      'Example::re3' => (variant => 'B'),  # supply generator arguments
      'JSON::*' => (-prefix => 'json_'),   # add prefix
      'License::*' => (
-       -has_tag    => 'family:cc',        # select by tag
-       -lacks_tag  => 'type:unversioned', #   also select by lack of tag
-       -suffix     => '_license',         #   also add suffix
+       # filtering options
+       -has_tag    => 'family:cc',        # only select patterns that has this tag
+       -lacks_tag  => 'type:unversioned', # only select patterns that does not have this tag
+       -has_tag_matching   => qr/^type:/, # only select patterns that has a tag matching this regex
+       -lacks_tag_matching => qr/^type:/, # only select patterns that does not have any tags matching this regex
+
+       # other options
+       -prefix  => 'pat_',       # add prefix
+       -suffix  => '_license',   # add suffix
      ),
  );
 
@@ -194,15 +212,19 @@ your program.
  
      # more complete spec
      re2 => {
-         summary => 'This is regexp for blah',
+         summary => 'This is regexp for blah', # plaintext
          description => <<'_',
  
- A longer description.
+ A longer description in *Markdown* format.
  
  _
          pat => qr/\d{3}-\d{3}(?:-\d{5})?/,
          tags => ['A','B'],
          examples => [
+             # examples can be tested using 'test-regexp-pattern' script
+             # (distributed in Test-Regexp-Pattern distribution). examples can
+             # also be rendered in your POD using
+             # Pod::Weaver::Plugin::Regexp::Pattern.
              {
                  str => '123-456',
                  matches => 1,
@@ -275,6 +297,9 @@ your program.
  
      re4 => {
          summary => 'This is a regexp that does capturing',
+         # it is recommended that your pattern does not capture, unless
+         # necessary. capturing pattern should tag with 'capturing' to let
+         # users/tools know.
          tags => ['capturing'],
          pat => qr/(\d{3})-(\d{3})/,
          examples => [
@@ -284,7 +309,10 @@ your program.
      },
  
      re5 => {
-         summary => 'This is another regexp that does (named) capturing and anchoring',
+         summary => 'This is another regexp that is anchored and does (named) capturing',
+         # it is recommended that your pattern is not anchored for more
+         # reusability, unless necessary. anchored pattern should tag with
+         # 'anchored' to let users/tools know.
          tags => ['capturing', 'anchored'],
          pat => qr/^(?<cap1>\d{3})-(?<cap2>\d{3})/,
          examples => [
@@ -319,7 +347,7 @@ description, tags, and so on, for example (taken from L<Regexp::Pattern::CPAN>):
      HERE
      examples => [
          {str=>'PERLANCAR', matches=>1},
-         {str=>'BAD ID', matches=>0},
+         {str=>'BAD ID', anchor=>1, matches=>0},
      ],
  }
 
@@ -389,7 +417,9 @@ name:
 B<Filtering.> When wildcard-importing, you can select the patterns you want
 using a combination of these options: C<-has_tag> (only select patterns that
 have a specified tag), C<-lacks_tag> (only select patterns that do not have a
-specified tag).
+specified tag), C<-has_tag_matching> (only select patterns that has at least one
+tag matching specified regex pattern), C<-lacks_tag_matching> (only select
+patterns that does not have any tags matching specified regex pattern).
 
 =head2 Recommendations for writing the regex patterns
 
@@ -428,7 +458,7 @@ Adding capture groups limits the reusability of the pattern because it can
 affect the groups of the composed pattern. When composing pattern, user can add
 captures herself if needed.
 
-When you define an anchored pattern, adding tag C<capturing> is recommended:
+When you define a capturing pattern, adding tag C<capturing> is recommended:
 
  tags => ['capturing'],
 
@@ -457,6 +487,27 @@ conveniently wraps the regex inside C<< qr/\A(?:...)\z/ >>.
 Die when pattern by name C<$name> cannot be found (either the module cannot be
 loaded or the pattern with that name is not found in the module).
 
+=head1 FAQ
+
+=head2 My pattern is not anchored, but what if I want to test the anchored version?
+
+You can add C<< anchor=>1 >> or C<< gen_args=>{-anchor=>1} >> in the example,
+for example:
+
+ {
+     summary     => 'PAUSE author ID, or PAUSE ID for short',
+     pat         => qr/[A-Z][A-Z0-9]{1,8}/,
+     description => <<~HERE,
+     I'm not sure whether PAUSE allows digit for the first letter. For safety
+     I'm assuming no.
+     HERE
+     examples => [
+         {str=>'PERLANCAR', matches=>1},
+         {str=>'BAD ID', anchor=>1, matches=>0, summary=>"Contains whitespace"},
+         {str=>'NAMETOOLONG', gen_args=>{-anchor=>1}, matches=>0, summary=>"Too long"},
+     ],
+ }
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Regexp-Pattern>.
@@ -502,7 +553,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
