@@ -1,7 +1,7 @@
 package Regexp::Pattern::Example;
 
-our $DATE = '2018-09-12'; # DATE
-our $VERSION = '0.2.8'; # VERSION
+our $DATE = '2020-02-07'; # DATE
+our $VERSION = '0.2.12'; # VERSION
 
 use 5.010001;
 
@@ -13,15 +13,19 @@ our %RE = (
 
     # more complete spec
     re2 => {
-        summary => 'This is regexp for blah',
+        summary => 'This is regexp for blah', # plaintext
         description => <<'_',
 
-A longer description.
+A longer description in *Markdown* format.
 
 _
         pat => qr/\d{3}-\d{3}(?:-\d{5})?/,
         tags => ['A','B'],
         examples => [
+            # examples can be tested using 'test-regexp-pattern' script
+            # (distributed in Test-Regexp-Pattern distribution). examples can
+            # also be rendered in your POD using
+            # Pod::Weaver::Plugin::Regexp::Pattern.
             {
                 str => '123-456',
                 matches => 1,
@@ -94,6 +98,9 @@ _
 
     re4 => {
         summary => 'This is a regexp that does capturing',
+        # it is recommended that your pattern does not capture, unless
+        # necessary. capturing pattern should tag with 'capturing' to let
+        # users/tools know.
         tags => ['capturing'],
         pat => qr/(\d{3})-(\d{3})/,
         examples => [
@@ -103,7 +110,10 @@ _
     },
 
     re5 => {
-        summary => 'This is another regexp that does (named) capturing and anchoring',
+        summary => 'This is another regexp that is anchored and does (named) capturing',
+        # it is recommended that your pattern is not anchored for more
+        # reusability, unless necessary. anchored pattern should tag with
+        # 'anchored' to let users/tools know.
         tags => ['capturing', 'anchored'],
         pat => qr/^(?<cap1>\d{3})-(?<cap2>\d{3})/,
         examples => [
@@ -130,7 +140,7 @@ Regexp::Pattern::Example - An example Regexp::Pattern::* module
 
 =head1 VERSION
 
-This document describes version 0.2.8 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2018-09-12.
+This document describes version 0.2.12 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2020-02-07.
 
 =head1 SYNOPSIS
 
@@ -151,20 +161,23 @@ L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
 
 This is regexp for blah.
 
-A longer description.
+A longer description in I<Markdown> format.
 
 
 Examples:
 
  "123-456" =~ re("Example::re2");  # matches
 
- # Another example that matches
+Another example that matches.
+
  "123-456-78901" =~ re("Example::re2");  # matches
 
- # An example that does not match
+An example that does not match.
+
  123456 =~ re("Example::re2");  # doesn't match
 
- # An example that does not get tested
+An example that does not get tested.
+
  123456 =~ re("Example::re2");  # doesn't match
 
 =item * re3
@@ -190,10 +203,12 @@ Choose variant.
 
 Examples:
 
- # An example that matches
+An example that matches.
+
  "123-456" =~ re("Example::re3", {variant=>"A"});  # matches
 
- # An example that doesn't match
+An example that doesn't match.
+
  "123-456" =~ re("Example::re3", {variant=>"B"});  # doesn't match
 
 =item * re4
@@ -208,7 +223,7 @@ Examples:
 
 =item * re5
 
-This is another regexp that does (named) capturing and anchoring.
+This is another regexp that is anchored and does (named) capturing.
 
 Examples:
 
@@ -240,7 +255,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
